pub struct BufReader<R> { /* private fields */ }Expand description
The BufReader struct adds buffering to any reader.
It can be excessively inefficient to work directly with a Read instance.
For example, every call to read on TcpStream
results in a system call. A BufReader performs large, infrequent reads on
the underlying Read and maintains an in-memory buffer of the results.
BufReader can improve the speed of programs that make small and
repeated read calls to the same file or network socket. It does not
help when reading very large amounts at once, or reading just one or a few
times. It also provides no advantage when reading from a source that is
already in memory, like a Vec<u8>.
Examples
use std::io::prelude::*;
use std::io::BufReader;
use std::fs::File;
fn main() -> std::io::Result<()> {
let f = File::open("log.txt")?;
let mut reader = BufReader::new(f);
let mut line = String::new();
let len = reader.read_line(&mut line)?;
println!("First line is {} bytes long", len);
Ok(())
}Implementations
Sourceimpl<R: Read> BufReader<R>
impl<R: Read> BufReader<R>
Sourcepub fn new(inner: R) -> BufReader<R>
pub fn new(inner: R) -> BufReader<R>
Creates a new BufReader with a default buffer capacity. The default is currently 8 KB,
but may change in the future.
Examples
use std::io::BufReader;
use std::fs::File;
fn main() -> std::io::Result<()> {
let f = File::open("log.txt")?;
let reader = BufReader::new(f);
Ok(())
}Sourcepub fn with_capacity(cap: usize, inner: R) -> BufReader<R>
pub fn with_capacity(cap: usize, inner: R) -> BufReader<R>
Creates a new BufReader with the specified buffer capacity.
Examples
Creating a buffer with ten bytes of capacity:
use std::io::BufReader;
use std::fs::File;
fn main() -> std::io::Result<()> {
let f = File::open("log.txt")?;
let reader = BufReader::with_capacity(10, f);
Ok(())
}Sourcepub fn get_ref(&self) -> &R
pub fn get_ref(&self) -> &R
Gets a reference to the underlying reader.
It is inadvisable to directly read from the underlying reader.
Examples
use std::io::BufReader;
use std::fs::File;
fn main() -> std::io::Result<()> {
let f1 = File::open("log.txt")?;
let reader = BufReader::new(f1);
let f2 = reader.get_ref();
Ok(())
}Sourceimpl<R: Seek> BufReader<R>
impl<R: Seek> BufReader<R>
Sourcepub fn seek_relative(&mut self, offset: i64) -> Result<()>
pub fn seek_relative(&mut self, offset: i64) -> Result<()>
Seeks relative to the current position. If the new position lies within the buffer, the buffer will not be flushed, allowing for more efficient seeks. This method does not return the location of the underlying reader, so the caller must track this information themselves if it is required.